@@ -460,7 +460,12 @@ xfce_appfinder_model_get_value (GtkTreeModel *tree_model,
               comment = garcon_menu_item_get_comment (item->item);
 
               if (comment != NULL)
-                item->abstract = g_markup_printf_escaped ("<b>%s</b>\n%s", name, comment);
+                {
+                  if (model->icon_size < XFCE_APPFINDER_ICON_SIZE_SMALL)
+                    item->abstract = g_markup_printf_escaped ("<b>%s</b> &#8212; %s", name, comment);
+                  else
+                    item->abstract = g_markup_printf_escaped ("<b>%s</b>\n%s", name, comment);
+                }
               else
                 item->abstract = g_markup_printf_escaped ("<b>%s</b>", name);
             }
@@ -1884,6 +1889,7 @@ xfce_appfinder_model_load_pixbuf (const gchar           *icon_name,
     case XFCE_APPFINDER_ICON_SIZE_LARGE:    size = 64;  break;
     case XFCE_APPFINDER_ICON_SIZE_LARGER:   size = 96;  break;
     case XFCE_APPFINDER_ICON_SIZE_LARGEST:  size = 128; break;
+    default: return NULL;
     }
 
   APPFINDER_DEBUG ("load icon %s at %dpx", icon_name, size);
@@ -2084,6 +2090,12 @@ xfce_appfinder_model_icon_theme_changed (XfceAppfinderModel *model)
           item->icon_large = NULL;
           item_changed = TRUE;
         }
+      if (item->abstract != NULL)
+        {
+          g_free (item->abstract);
+          item->abstract = NULL;
+          item_changed = TRUE;
+        }
 
       if (item->item == NULL)
         {
